[Pkg-owncloud-commits] [owncloud] 63/75: Update ctag in deleteFromDAVData.

David Prévot taffit at alioth.debian.org
Fri Nov 8 23:08:43 UTC 2013


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to annotated tag v3.0.1
in repository owncloud.

commit f6718dd889d995b0142334e8336036586984dc7f
Author: Thomas Tanghus <thomas at tanghus.net>
Date:   Sun Feb 19 23:03:10 2012 +0100

    Update ctag in deleteFromDAVData.
---
 apps/contacts/lib/vcard.php |    3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/apps/contacts/lib/vcard.php b/apps/contacts/lib/vcard.php
index b174ed4..4771363 100644
--- a/apps/contacts/lib/vcard.php
+++ b/apps/contacts/lib/vcard.php
@@ -276,7 +276,7 @@ class OC_Contacts_VCard{
 	 * @return boolean
 	 */
 	public static function delete($id){
 		// FIXME: Add error checking.
 		$stmt = OC_DB::prepare( 'DELETE FROM *PREFIX*contacts_cards WHERE id = ?' );
 		$stmt->execute(array($id));
 
@@ -301,6 +301,7 @@ class OC_Contacts_VCard{
 		// FIXME: Add error checking. Deleting a card gives an Kontact/Akonadi error.
 		$stmt = OC_DB::prepare( 'DELETE FROM *PREFIX*contacts_cards WHERE addressbookid = ? AND uri=?' );
 		$stmt->execute(array($aid,$uri));
+		OC_Contacts_Addressbook::touch($aid);
 
 		return true;
 	}
@@ -276,7 +276,7 @@ class OC_Contacts_VCard{
 	 */
 	public static function delete($id){
-		// FIXME: Add error checking.
+		// FIXME: Add error checking. Touch addressbook.
 		$stmt = OC_DB::prepare( 'DELETE FROM *PREFIX*contacts_cards WHERE id = ?' );
 		$stmt->execute(array($id));

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud.git



More information about the Pkg-owncloud-commits mailing list